django-misfit
===============
[![Build Status](https://travis-ci.org/orcasgit/django-misfit.svg?branch=master)](https://travis-ci.org/orcasgit/django-misfit) [![Coverage Status](https://coveralls.io/repos/orcasgit/django-misfit/badge.png)](https://coveralls.io/r/orcasgit/django-misfit) [![Requirements Status](https://requires.io/github/orcasgit/django-misfit/requirements.png?branch=master)](https://requires.io/github/orcasgit/django-misfit/requirements/?branch=master)

Django-misfit is a Django app for integrating a user's Misfit data into your
site.

It handles the details of getting your app authorized to access your user's
Misfit data via the [Misfit API](https://build.misfit.com/docs/).
